Crate pochoir_extra

Crate pochoir_extra 

A collection of extra tools to transform components.

  • CSS enhancer: used to apply various transforms to <style> CSS elements, support scoped CSS, CSS nesting, CSS minification, CSS autoprefixer and polyfiller
  • Accessibility checker used to check the accessibility of the page in real time in debug mode

Re-exports

pub use accessibility_checker::AccessibilityChecker;
pub use enhanced_css::EnhancedCss;
pub use enhanced_css::EnhancedCssBundler;

Modules

accessibility_checker
Accessibility checker used to display accessibility reports in debug mode using axe-core.
enhanced_css
CSS enhancer using the awesome lightningcss crate.